aboutsummaryrefslogtreecommitdiff
path: root/src/Haddock/Interface.hs
diff options
context:
space:
mode:
authorDavid Waern <david.waern@gmail.com>2009-07-06 21:44:10 +0000
committerDavid Waern <david.waern@gmail.com>2009-07-06 21:44:10 +0000
commit80d29d2fb322ddbb8d6eacac437216841b4d252c (patch)
tree27ae77b36bbd6d11bcd867e74ee2b148104e73a5 /src/Haddock/Interface.hs
parentdb1f0bf4cc035562820233965e7b2845ed867c2e (diff)
Use HscAsm instead of HscC when using TH
Diffstat (limited to 'src/Haddock/Interface.hs')
-rw-r--r--src/Haddock/Interface.hs8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/Haddock/Interface.hs b/src/Haddock/Interface.hs
index ffb9ebaf..b9d409db 100644
--- a/src/Haddock/Interface.hs
+++ b/src/Haddock/Interface.hs
@@ -102,10 +102,10 @@ createInterfaces' verbosity modules flags instIfaceMap = do
modgraph' <- if needsTemplateHaskell modgraph
then do
dflags <- getSessionDynFlags
- _ <- setSessionDynFlags dflags { hscTarget = HscC }
- -- we need to set HscC on all the ModSummaries as well
- let addHscC m = m { ms_hspp_opts = (ms_hspp_opts m) { hscTarget = HscC } }
- return (map addHscC modgraph)
+ _ <- setSessionDynFlags dflags { hscTarget = HscAsm }
+ -- we need to set HscAsm on all the ModSummaries as well
+ let addHscAsm m = m { ms_hspp_opts = (ms_hspp_opts m) { hscTarget = HscAsm } }
+ return (map addHscAsm modgraph)
else return modgraph
#else
let modgraph' = modgraph